@@ -26,11 +26,11 @@ import urllib.parse
 import zipfile
 
 from cubicweb import Unauthorized
-from cubicweb.view import View
+from cubicweb_web.view import View
 from cubicweb.predicates import none_rset
 from cubicweb.appobject import AppObject
-from cubicweb.web import httpcache
-from cubicweb.web.views.urlrewrite import SimpleReqRewriter, rgx
+from cubicweb_web import httpcache
+from cubicweb_web.views.urlrewrite import SimpleReqRewriter, rgx
 
 
 class SeoReqRewriter(SimpleReqRewriter):
